# PaymentServiceDefinitionFields

A single field that needs to be submitted for a payment service when it is created.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**key** | **str** | The key of a field that needs to be submitted. | [optional] 
**display_name** | **str** | The name to display for a field in the dashboard. | [optional] 
**required** | **bool** | Defines if this field is required when the service is created. | [optional] 
**format** | **str** | Defines the type of input that needs to be rendered for this field. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


